@@ -101,18 +101,22 @@ class Domoticz(IPlugin):
 #				log.msg("*********************************************  : ")
 #				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
 				for rt in jsonreq['result'] :
-					log.msg(" jsonreq - idx   :  %s" % (rt['idx']))
-					log.msg("   jsonreq - type   :  %s" % (rt['Type']))
+					log.msg(" jsonreq - NT - idx   :  %s" % (rt['idx']))
+					log.msg("   jsonreq - NT  - type   :  %s" % (rt['Type']))
+					log.msg(" jsonreq - NT  - batlevel   :  %s" % (rt['BatteryLevel']))
+					log.msg(" jsonreq - NT  - Temp   :  %s" % (rt['Temp']))
+					log.msg(" jsonreq - NT  - Name   :  %s" % (rt['Name']))
+					log.msg(" jsonreq - NT  - Data   :  %s" % (rt['Data']))
 					if int(rs['idx']) == rt['idx']:
 						log.msg(" jsonreq - idx   :  %s" % (rt['idx']))
 						log.msg(" jsonreq - batlevel   :  %s" % (rt['BatteryLevel']))
-						log.msg(" jsonreq - idx   :  %s" % (rt['Temp']))
-						log.msg(" jsonreq - idx   :  %s" % (rt['Name']))
-						log.msg(" jsonreq - idx   :  %s" % (rt['Data']))
+						log.msg(" jsonreq - Temp   :  %s" % (rt['Temp']))
+						log.msg(" jsonreq - Name   :  %s" % (rt['Name']))
+						log.msg(" jsonreq - Data   :  %s" % (rt['Data']))
 							
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
-			"method": "switchlight",
+			"method": "devices",
 			"body": bodies
 		}
